@@ -1,4 +1,4 @@
-#!/usr/bin/python2
+#!/usr/bin/python3
 # -*- coding: UTF-8 -*-
 
 ############################################################################
@@ -44,9 +44,11 @@ from signal import SIGTERM, SIGKILL
 import signal
 signal.signal(signal.SIGINT, signal.SIG_DFL)
 
+import codecs
+
 import gettext
-gettext.bindtextdomain('nemo-terminal', '@prefix@/share/locale')
-gettext.textdomain('nemo-terminal')
+gettext.bindtextdomain("nemo-extensions")
+gettext.textdomain("nemo-extensions")
 _ = gettext.gettext
 
 import gi
@@ -54,13 +56,6 @@ gi.require_version('Vte', '2.91')
 gi.require_version('Nemo', '3.0')
 from gi.repository import GObject, Nemo, Gtk, Gdk, Vte, GLib, Gio
 
-# DEFAULT_CONF = {
-#         'general/def_term_height': 5, #lines
-#         'general/def_visible': False,
-#         'general/term_on_top': True,
-#         'terminal/shell': Vte.get_user_shell(),
-#         }
-
 BASE_KEY = "org.nemo.extensions.nemo-terminal"
 settings = Gio.Settings.new(BASE_KEY)
 
@@ -87,6 +82,8 @@ class NemoTerminal(object):
         self.shell_pid = -1
         self.term = Vte.Terminal()
 
+        settings.bind("audible-bell", self.term, "audible-bell", Gio.SettingsBindFlags.GET)
+
         self.shell_pid = self.term.spawn_sync(Vte.PtyFlags.DEFAULT, self._path, [terminal_or_default()], None, GLib.SpawnFlags.SEARCH_PATH, None, None, None)[1]
 
         # Make vte.sh active
@@ -203,7 +200,7 @@ class NemoTerminal(object):
             workingDir = os.readlink('/proc/%s/cwd' % pgroup)
         gfile = Gio.file_parse_name(workingDir)
         workingDirUri = gfile.get_uri()
-        print workingDirUri
+        print( workingDirUri)
         # TODO: something useful (like changing the working dir)
         return
 
@@ -242,18 +239,19 @@ class NemoTerminal(object):
 
         if not self._shell_is_busy():
             # Clear any input
-            eraselinekeys = settings.get_string("terminal-erase-line").decode('string_escape')
-            self.feed_child(eraselinekeys)
+
+            eraselinekeys = settings.get_string("terminal-erase-line")
+            self.feed_child(eraselinekeys.encode().decode("unicode_escape"))
 
             # Change directory
             cdcmd_nonewline = settings.get_string("terminal-change-directory-command") \
                 % GLib.shell_quote(self._path)
             cdcmd = "%s\n" % cdcmd_nonewline
-            self.feed_child(cdcmd)
+            self.feed_child(cdcmd.encode().decode("unicode_escape"))
 
             # Restore user input
-            restorelinekeys = settings.get_string("terminal-restore-line").decode('string_escape')
-            self.feed_child(restorelinekeys)
+            restorelinekeys = settings.get_string("terminal-restore-line")
+            self.feed_child(restorelinekeys.encode().decode("unicode_escape"))
 
     def get_widget(self):
         """Return the top-level widget of Nemo Terminal."""
@@ -408,10 +406,14 @@ class NemoTerminal(object):
         gobject-introspection/python-gi differences force us to try with and
         without the text length. One of them will work.
         """
+        # print(type(text), "feed '%s'" % text)
         try:
-            self.term.feed_child(text)
+            self.term.feed_child(text.encode())
         except TypeError:
-            self.term.feed_child(text, len(text))
+            try:
+                self.term.feed_child(text, len(text))
+            except TypeError:
+                self.term.feed_child(text.encode(), len(text))
 
 class Crowbar(object):
     """Modify the Nemo' widget tree when the crowbar is inserted in it.
@@ -473,10 +475,7 @@ class Crowbar(object):
             vpan.show()
             vbox = Gtk.VBox()
             vbox.show()
-            if settings.get_enum("terminal-position") == 0:
-                vpan.add2(vbox)
-            else:
-                vpan.add1(vbox)
+
             #Add the vpan in Nemo, and reparent some widgets
             if len(crowbar_pp_children) == 2:
                 for crowbar_pp_child in crowbar_pp_children:
@@ -484,15 +483,19 @@ class Crowbar(object):
                 crowbar_pp.pack_start(vpan, True, True, 0)
                 vbox.pack_start(crowbar_pp_children[0], False, False, 0)
                 vbox.pack_start(crowbar_pp_children[1], True, True, 0)
-            #Create the terminal
+
             nterm = NemoTerminal(self._uri, self._window)
 
             if hasattr(self._window, "term_visible"):
                 nterm.set_visible(self._window.term_visible)
+
             if settings.get_enum("terminal-position") == 0:
-                vpan.add1(nterm.get_widget())
+                vpan.pack1(nterm.get_widget(), False, False)
+                vpan.pack2(vbox, True, False)
             else:
-                vpan.add2(nterm.get_widget())
+                vpan.pack2(nterm.get_widget(), False, False)
+                vpan.pack1(vbox, True, False)
+
 
     def _on_crowbar_pp_parent_set(self, widget, old_parent):
         """Called when the vpan parent lost his parent.
@@ -571,7 +574,7 @@ class NemoTerminalProvider(GObject.GObject, Nemo.LocationWidgetProvider, Nemo.Na
         return Gdk.EVENT_PROPAGATE
 
     def get_name_and_desc(self):
-        return [("Nemo Terminal:::Embedded terminal for Nemo")]
+        return [("Nemo Terminal:::Embedded terminal for Nemo:::nemo-terminal-prefs")]
 
 if __name__ == "__main__":
     #Code for testing Nemo Terminal outside of Nemo
